@@ -1,5 +1,5 @@
-# Gufw 17.10.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw 19.10.0 - http://gufw.org
+# Copyright (C) 2008-2019 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ class Gufw:
                    2: 'log-all'}
 
     def __init__(self, frontend):
-        self.fw = frontend
+        self.frontend = frontend
         
         self.builder = Gtk.Builder()
         self.builder.set_translation_domain('gufw')
@@ -196,6 +196,7 @@ class Gufw:
         vbox_log = Gtk.Box()
         self.viewport_log  = self.builder.get_object('viewport_log')
         self.viewport_log.reparent(vbox_log)
+        # Translators: Noun
         stack.add_titled(vbox_log, "log", _("Log"))
         # Stack Compose
         stack_switcher = Gtk.StackSwitcher()
@@ -213,36 +214,39 @@ class Gufw:
         self.stack_vbox.pack_end(stack, True, True, 0)
     
     def _set_initial_values(self):
-        for profile in self.fw.get_all_profiles():
+        for profile in self.frontend.get_all_profiles():
             self.profile.append_text(profile)
-        self.profile.set_active(self.fw.get_all_profiles().index(self.fw.get_profile()))
+        self.profile.set_active(self.frontend.get_all_profiles().index(self.frontend.get_profile()))
         
-        self.switchStatus.set_active(self.fw.get_status())
+        self.switchStatus.set_active(self.frontend.get_status())
         
-        self.incoming.set_active(self.POLICY2NUM[self.fw.get_policy('incoming')])
-        self.outgoing.set_active(self.POLICY2NUM[self.fw.get_policy('outgoing')])
-        self.routed.set_active(self.POLICY2NUM[self.fw.get_policy('routed')])
-        self.incoming.set_sensitive(self.fw.get_status())
-        self.outgoing.set_sensitive(self.fw.get_status())
-        self.routed.set_sensitive(self.fw.get_status())
-        self.show_add_btn.set_sensitive(self.fw.get_status())
-        self.detele_rule_btn.set_sensitive(self.fw.get_status())
-        self.edit_rule_btn.set_sensitive(self.fw.get_status())
-        self.report_rule_btn.set_sensitive(self.fw.get_status())
+        self.incoming.set_active(self.POLICY2NUM[self.frontend.get_policy('incoming')])
+        self.outgoing.set_active(self.POLICY2NUM[self.frontend.get_policy('outgoing')])
+        self.routed.set_active(self.POLICY2NUM[self.frontend.get_policy('routed')])
+        self.incoming.set_sensitive(self.frontend.get_status())
+        self.outgoing.set_sensitive(self.frontend.get_status())
+        self.routed.set_sensitive(self.frontend.get_status())
+        self.show_add_btn.set_sensitive(self.frontend.get_status())
+        self.detele_rule_btn.set_sensitive(self.frontend.get_status())
+        self.edit_rule_btn.set_sensitive(self.frontend.get_status())
+        self.report_rule_btn.set_sensitive(self.frontend.get_status())
         
         render_txt = Gtk.CellRendererText()
         
         # Rules
+        # Translators: Number of  rule
         tree_header = Gtk.TreeViewColumn(_("Nº"), render_txt, text=14, foreground=13)
         tree_header.set_resizable(True)
         tree_header.set_sort_column_id(14)
         tree_header.set_sizing(1)
         self.tv_rules.append_column(tree_header)
+        # Translators: Of rule
         tree_header = Gtk.TreeViewColumn(_("Rule"), render_txt, text=0, foreground=13)
         tree_header.set_resizable(True)
         tree_header.set_sort_column_id(0)
         tree_header.set_sizing(1)
         self.tv_rules.append_column(tree_header)
+        # Translators: Of rule
         tree_header = Gtk.TreeViewColumn(_("Name"), render_txt, text=1, foreground=13)
         tree_header.set_resizable(True)
         tree_header.set_sort_column_id(1)
@@ -250,6 +254,7 @@ class Gufw:
         self.tv_rules.append_column(tree_header)
         
         # Listening Report
+        # Translators: Number of  rule
         tree_header = Gtk.TreeViewColumn(_("Nº"), render_txt, text=5, foreground=4)
         tree_header.set_resizable(True)
         tree_header.set_sort_column_id(5)
@@ -277,7 +282,7 @@ class Gufw:
         
         self.listening = ListeningReport(self)
         
-        self.add_to_log(self.fw.get_log(), self.GRAY, False)
+        self.add_to_log(self.frontend.get_log(), self.GRAY, False)
         
         self._load_tutorial()
         
@@ -286,12 +291,11 @@ class Gufw:
         self._restore_window_size(self.winMain)
         self.winMain.show_all()
         
-        if self.fw.get_policy('routed') == 'disabled':
+        if self.frontend.get_policy('routed') == 'disabled':
             self.routed_lbl.set_visible(False)
             self.box_routed.set_visible(False)
         
-        if self.fw.get_status():
-            self.print_rules(self.fw.get_rules())
+        self.print_rules(self.frontend.get_rules(False))
         
         self.btn_report_play.hide()
 
@@ -368,11 +372,11 @@ class Gufw:
             self.show_dialog(self.winMain, _("Error"), _("Filename has not valid characters. Rename the file\nto only letters, numbers, dashes and underscores"))
             return
         
-        if profile in self.fw.get_all_profiles():
+        if profile in self.frontend.get_all_profiles():
             self.set_statusbar_msg(_("Operation cancelled"))
             self.show_dialog(self.winMain, _("Profile already exists"), _("Delete it before from the Preferences Window or rename the file (the profile will be the filename)"))
         else:
-            self.fw.import_profile(import_profile)
+            self.frontend.import_profile(import_profile)
             self.profile.append_text(profile)
             self.add_to_log(_("Profile imported: ") + import_profile)
             self.set_statusbar_msg(_("Profile imported, now you can choose it in the profiles"))
@@ -387,7 +391,7 @@ class Gufw:
         if export_profile[-8:] != '.profile':
             export_profile = export_profile + '.profile'
         
-        self.fw.export_profile(export_profile)
+        self.frontend.export_profile(export_profile)
         self.add_to_log(_("Profile exported: ") + export_profile)
         self.set_statusbar_msg(_("Profile exported"))
     
@@ -403,10 +407,10 @@ class Gufw:
         Gtk.main_quit()
     
     def _set_shield(self):
-        if self.fw.get_status():
-            file_shield = os.path.join('/usr/share/gufw/media/shields/', self.fw.get_policy('incoming').lower() + '_' + self.fw.get_policy('outgoing').lower() + '_' + self.fw.get_policy('routed').lower() + '.png')
+        if self.frontend.get_status():
+            file_shield = os.path.join('/usr/share/gufw/media/shields/', self.frontend.get_policy('incoming').lower() + '_' + self.frontend.get_policy('outgoing').lower() + '_' + self.frontend.get_policy('routed').lower() + '.png')
         else:
-            if self.fw.get_policy('routed') == 'disabled':
+            if self.frontend.get_policy('routed') == 'disabled':
                 file_shield = os.path.join('/usr/share/gufw/media/shields/', 'disabled_disabled_disabled.png')
             else:
                 file_shield = os.path.join('/usr/share/gufw/media/shields/', 'disabled_disabled_enabled.png')
@@ -415,20 +419,20 @@ class Gufw:
     def on_menu_reset_activate(self, widget, data=None):
         answer = self._show_question(self.winMain, _("Reset Firewall"), _("This will remove all rules in the current\nprofile and disable the firewall"), _("Do you want to continue?"))
         if answer:
-            if self.fw.get_status():
+            if self.frontend.get_status():
                 self.switchStatus.set_active(False)
-            self.fw.reset()
+            self.frontend.reset()
             self.add_to_log(_("Removed rules and reset firewall!"))
     
     def on_btnLogRemove_clicked(self, widget, data=None):
-        self.fw.refresh_log()
+        self.frontend.refresh_log()
         self.log_txt.set_text('')
         self.add_to_log(_("Gufw Log: Removed"))
         self.set_statusbar_msg(_("Gufw Log removed"))
     
     def on_btnLogCopy_clicked(self, widget, data=None):
         self.clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-        self.clipboard.set_text(self.fw.get_log(), -1)
+        self.clipboard.set_text(self.frontend.get_log(), -1)
         self.set_statusbar_msg(_("Text copied to clipboard"))
     
     def on_donate_btn_clicked(self, widget, data=None):
@@ -468,30 +472,32 @@ class Gufw:
         preferenceswin = Preferences(self)
     
     def on_incoming_changed(self, widget, data=None):
-        self.fw.set_policy('incoming', self.NUM2POLICY[self.incoming.get_active()].lower())
+        self.frontend.set_policy('incoming', self.NUM2POLICY[self.incoming.get_active()].lower())
         self._set_shield()
-        self.add_to_log(_("Incoming: ") + self.incoming.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('incoming')])
+        # Translators: Policy
+        self.add_to_log(_("Incoming: ") + self.incoming.get_active_text(), self.POLICY2COLOR[self.frontend.get_policy('incoming')])
         self.set_statusbar_msg(_("Incoming policy changed"))
-        if self.fw.get_policy('incoming') != self.NUM2POLICY[self.incoming.get_active()].lower():
+        if self.frontend.get_policy('incoming') != self.NUM2POLICY[self.incoming.get_active()].lower():
             self.show_dialog(self.winMain, _("There was an error changing the incoming policy"), _("Restart your firewall to refresh to the real status\nand please report this bug"))
     
     def on_outgoing_changed(self, widget, data=None):
-        self.fw.set_policy('outgoing', self.NUM2POLICY[self.outgoing.get_active()].lower())
+        self.frontend.set_policy('outgoing', self.NUM2POLICY[self.outgoing.get_active()].lower())
         self._set_shield()
-        self.add_to_log(_("Outgoing: ") + self.outgoing.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('outgoing')])
+        self.add_to_log(_("Outgoing: ") + self.outgoing.get_active_text(), self.POLICY2COLOR[self.frontend.get_policy('outgoing')])
         self.set_statusbar_msg(_("Outgoing policy changed"))
-        if self.fw.get_policy('outgoing') != self.NUM2POLICY[self.outgoing.get_active()].lower():
+        if self.frontend.get_policy('outgoing') != self.NUM2POLICY[self.outgoing.get_active()].lower():
             self.show_dialog(self.winMain, _("There was an error changing the outgoing policy"), _("Restart your firewall to refresh to the real status\nand please report this bug"))
     
     def on_routed_changed(self, widget, data=None):
         try: # Could be inconsistent between imports and changes of Routed status
-            self.fw.set_policy('routed', self.NUM2POLICY[self.routed.get_active()].lower())
+            self.frontend.set_policy('routed', self.NUM2POLICY[self.routed.get_active()].lower())
         except Exception:
             return
         self._set_shield()
-        self.add_to_log(_("Routed: ") + self.routed.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('routed')])
+        # Translators: Routed firewall changed
+        self.add_to_log(_("Routed: ") + self.routed.get_active_text(), self.POLICY2COLOR[self.frontend.get_policy('routed')])
         self.set_statusbar_msg(_("Routed policy changed"))
-        if self.fw.get_policy('routed') != self.NUM2POLICY[self.routed.get_active()].lower():
+        if self.frontend.get_policy('routed') != self.NUM2POLICY[self.routed.get_active()].lower():
             self.show_dialog(self.winMain, _("There was an error changing the routed policy"), _("Restart your firewall to refresh to the real status\nand please report this bug"))
     
     def on_btnAddRule_clicked(self, widget, data=None):
@@ -533,25 +539,27 @@ class Gufw:
         self.listening.set_pause(False)
     
     def on_switchStatus_active_notify(self, widget, data=None):
-        self.fw.set_status(self.switchStatus.get_active())
-        self.print_rules(self.fw.get_rules())
+        self.frontend.set_status(self.switchStatus.get_active())
+        self.print_rules(self.frontend.get_rules(False))
         
-        if self.fw.get_status():
+        if self.frontend.get_status():
+            # Translators: About firewall
             self.add_to_log(_("Status: Enabled"), self.GREEN)
             self.set_statusbar_msg(_("Firewall enabled"))
         else:
+            # Translators: About firewall
             self.add_to_log(_("Status: Disabled"), self.RED)
             self.set_statusbar_msg(_("Firewall disabled"))
         
-        self.incoming.set_sensitive(self.fw.get_status())
-        self.outgoing.set_sensitive(self.fw.get_status())
-        self.routed.set_sensitive(self.fw.get_status())
-        self.show_add_btn.set_sensitive(self.fw.get_status())
-        self.detele_rule_btn.set_sensitive(self.fw.get_status())
-        self.edit_rule_btn.set_sensitive(self.fw.get_status())
-        self.report_rule_btn.set_sensitive(self.fw.get_status())
+        self.incoming.set_sensitive(self.frontend.get_status())
+        self.outgoing.set_sensitive(self.frontend.get_status())
+        self.routed.set_sensitive(self.frontend.get_status())
+        self.show_add_btn.set_sensitive(self.frontend.get_status())
+        self.detele_rule_btn.set_sensitive(self.frontend.get_status())
+        self.edit_rule_btn.set_sensitive(self.frontend.get_status())
+        self.report_rule_btn.set_sensitive(self.frontend.get_status())
         self._set_shield()
-        if self.fw.get_status() != self.switchStatus.get_active():
+        if self.frontend.get_status() != self.switchStatus.get_active():
             self.show_dialog(self.winMain, _("There was an error changing the firewall status"), _("Restart your firewall to refresh to the real status and please report this bug"))
 
     def on_btnDeleteRule_clicked(self, widget, data=None):
@@ -566,26 +574,27 @@ class Gufw:
         total_rules = sorted(total_rules, key=int, reverse=True)
         
         # Confirm?
-        if (self.fw.get_config_value('ConfirmDeteleRule') == 'yes') and (len(total_rules) > 0):
+        if (self.frontend.get_config_value('ConfirmDeteleRule') == 'yes') and (len(total_rules) > 0):
             answer = self._show_question(self.winMain, _("Delete rule"), _("You will delete all selected rules"), _("Do you want to continue?"))
             if not answer:
                 return
         
         for row in total_rules:
             rules_selected = True            
-            rules_before = self.fw.get_rules()
-            cmd = self.fw.delete_rule(row)
-            rules_after = self.fw.get_rules()
+            rules_before = self.frontend.get_rules()
+            cmd = self.frontend.delete_rule(row)
+            rules_after = self.frontend.get_rules()
             
             if len(rules_before) != len(rules_after):
                 self.add_to_log(cmd[0])
                 self.set_statusbar_msg(_("Rule(s) deleted"))
             else:
+                # Translators: Error running an ufw command
                 self.add_to_log(_("Error running: ") + cmd[0] + ' > ' + cmd[1].replace('\n', ' | '))
                 self.set_statusbar_msg(_("Error. Review Gufw Log"))
         
         if rules_selected:
-            self.print_rules(self.fw.get_rules())
+            self.print_rules(self.frontend.get_rules())
         else:
             self.show_dialog(self.winMain, _("No rule selected"), _("You have to select a rule"))
     
@@ -629,15 +638,15 @@ class Gufw:
         updatewin = Update(self, ufw_row, description, cmd, policy, direction, proto, from_ip, from_port, to_ip, to_port, iface, routed, logging)
 
     def on_profile_changed(self, widget, data=None):
-        operation = self.fw.set_profile(self.profile.get_active_text())
+        operation = self.frontend.set_profile(self.profile.get_active_text())
         self.add_to_log(_("Changing profile: ") + self.profile.get_active_text())
         
-        self.incoming.set_active(self.POLICY2NUM[self.fw.get_policy('incoming')])
-        self.outgoing.set_active(self.POLICY2NUM[self.fw.get_policy('outgoing')])
-        self.routed.set_active(self.POLICY2NUM[self.fw.get_policy('routed')])
-        self.switchStatus.set_active(self.fw.get_status())
+        self.incoming.set_active(self.POLICY2NUM[self.frontend.get_policy('incoming')])
+        self.outgoing.set_active(self.POLICY2NUM[self.frontend.get_policy('outgoing')])
+        self.routed.set_active(self.POLICY2NUM[self.frontend.get_policy('routed')])
+        self.switchStatus.set_active(self.frontend.get_status())
         
-        self.print_rules(self.fw.get_rules())
+        self.print_rules(self.frontend.get_rules())
         
         for msg in operation:
             self.add_to_log(msg)
@@ -678,11 +687,11 @@ class Gufw:
         return self.txt_tag_black
             
     def add_to_log(self, msg, color=BLACK, force_save=True):
-        if not self.fw.get_logging():
+        if not self.frontend.get_logging():
             return
         
         if force_save:
-            new_line = self.fw.add_to_log(msg)
+            new_line = self.frontend.add_to_log(msg)
             self.log_txt.insert_with_tags(self.log_txt.get_start_iter(), new_line, self._get_log_color(color)) 
         else:
             self.log_txt.insert_with_tags(self.log_txt.get_end_iter(), msg, self._get_log_color(color)) 
@@ -693,23 +702,35 @@ class Gufw:
     
     def print_rules(self, rules):
         self.rules_model.clear()
-        if not self.fw.get_status():
+        if not self.frontend.get_status():
             return
         
         row = 1
         for rule in (rules):
             iter_row = self.rules_model.insert(row)
+            # Translators: ufw string
             translated_rule = rule['ufw_rule'].replace(" ALLOW ",  _(" ALLOW "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" DENY ",    _(" DENY "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" REJECT ",  _(" REJECT "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" LIMIT ",   _(" LIMIT "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" OUT ",     _(" OUT "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" IN ",      _(" IN "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" FWD ",     _(" FWD "))
+            # Translators: ufw string
             translated_rule = translated_rule.replace("Anywhere",  _("Anywhere"))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" (log) ",     _("(log)"))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" (log-all) ", _("(log-all)"))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" (out)",    _(" (out)"))
+            # Translators: ufw string
             translated_rule = translated_rule.replace(" on ",      _(" on "))
             
             self.rules_model.set_value(iter_row, 0,  translated_rule)     # ufw rule
@@ -779,10 +800,10 @@ class Gufw:
         
         width = 0
         height = 0
-        if self.fw.get_config_value('WindowWidth'):
-            width = int(self.fw.get_config_value('WindowWidth'))
-        if self.fw.get_config_value('WindowHeight'):
-            height = int(self.fw.get_config_value('WindowHeight'))
+        if self.frontend.get_config_value('WindowWidth'):
+            width = int(self.frontend.get_config_value('WindowWidth'))
+        if self.frontend.get_config_value('WindowHeight'):
+            height = int(self.frontend.get_config_value('WindowHeight'))
         
         if width >= Gdk.Screen.width() and height >= Gdk.Screen.height():
             win.maximize()
@@ -791,8 +812,8 @@ class Gufw:
             
     def _save_window_size(self, win):
         width, height = win.get_size()
-        self.fw.set_config_value('WindowWidth',  str(width))
-        self.fw.set_config_value('WindowHeight', str(height))
+        self.frontend.set_config_value('WindowWidth',  str(width))
+        self.frontend.set_config_value('WindowHeight', str(height))
     
     def validate_rule(self, win, from_ip, from_port, to_ip, to_port, insert='', routed=''):
         # At least 1 Port/IP
@@ -805,7 +826,7 @@ class Gufw:
             insert_into = 0
         else:
             insert_into = int(insert)
-        if insert_into > 0 and insert_into > self.fw.get_number_rules():
+        if insert_into > 0 and insert_into > self.frontend.get_number_rules():
             self.show_dialog(win, _("Insert number bigger that number of rules"), _("By example, if you have 3 rules, you can't insert a rule into position 4"))
             return False
         
